@@ -9,6 +9,7 @@
 #include "operators/add_figure_of_text.h"
 #include "operators/add_figure_of_triangulation.h"
 #include "operators/add_figure_of_voxels_test.h"
+#include "operators/add_figures_of_primitive_directions.h"
 #include "operators/cad_score_many.h"
 #include "operators/cad_score.h"
 #include "operators/calculate_akbps.h"
@@ -60,6 +61,7 @@
 #include "operators/export_contacts_as_connected_mesh.h"
 #include "operators/export_contacts_as_pymol_cgo.h"
 #include "operators/export_contacts.h"
+#include "operators/export_directional_atom_type_tuples.h"
 #include "operators/export_figures_as_pymol_cgo.h"
 #include "operators/export_global_adjuncts.h"
 #include "operators/export_objects.h"
@@ -256,6 +258,7 @@ public:
 		set_command_for_data_manager("add-figure-of-text", operators::AddFigureOfText(), true);
 		set_command_for_data_manager("add-figure-of-triangulation", operators::AddFigureOfTriangulation(), true);
 		set_command_for_data_manager("add-figure-of-voxels-test", operators::AddFigureOfVoxelsTest(), true);
+		set_command_for_data_manager("add-figures-of-primitive-directions", operators::AddFiguresOfPrimitiveDirections(), true);
 		set_command_for_data_manager("calculate-akbps", operators::CalculateAKBPs(), true);
 		set_command_for_data_manager("calculate-akbps-layered", operators::CalculateAKBPsLayered(), true);
 		set_command_for_data_manager("calculate-betweenness", operators::CalculateBetweenness(), true);
@@ -291,6 +294,7 @@ public:
 		set_command_for_data_manager("export-contacts-as-connected-mesh", operators::ExportContactsAsConnectedMesh(), false);
 		set_command_for_data_manager("export-contacts-as-pymol-cgo", operators::ExportContactsAsPymolCGO(), false);
 		set_command_for_data_manager("export-contacts", operators::ExportContacts(), false);
+		set_command_for_data_manager("export-directional-atom-type-tuples", operators::ExportDirectionalAtomTypeTuples(), false);
 		set_command_for_data_manager("export-figures-as-pymol-cgo", operators::ExportFiguresAsPymolCGO(), false);
 		set_command_for_data_manager("export-selection-of-atoms", operators::ExportSelectionOfAtoms(), false);
 		set_command_for_data_manager("export-selection-of-contacts", operators::ExportSelectionOfContacts(), false);
